local internal = Medic.internal

local BaseModule = internal.class.BaseModule
local SocialListOfflineTimeFix = BaseModule:Subclass()

-- The last selected inventory category is discarded whenever the menu is closed.
-- This fix makes sure it stays selected like before
function SocialListOfflineTimeFix:New(...)
    return BaseModule.New(self, ...)
end

function SocialListOfflineTimeFix:Initialize()
    self.id = "SocialListOfflineTimeFix"
    self.optionLabel = "Fix Incorrect Offline Times"
    self.optionTooltip = "Turn it on to fix the offline times shown in guild roster and friend list"
    self.requiresReload = true
end

function SocialListOfflineTimeFix:Enable()
    local originalGetGuildMemberInfo = GetGuildMemberInfo
    GetGuildMemberInfo = function(guildId, memberIndex)
        local name, note, rankIndex, playerStatus, secsSinceLogoff = originalGetGuildMemberInfo(guildId, memberIndex)
        if secsSinceLogoff > 400000000 then
            secsSinceLogoff = GetTimeStamp() - secsSinceLogoff
        end
        return name, note, rankIndex, playerStatus, secsSinceLogoff
    end

    local originalGetFriendInfo = GetFriendInfo
    GetFriendInfo = function(friendIndex)
        local displayName, note, playerStatus, secsSinceLogoff = originalGetFriendInfo(friendIndex)
        if secsSinceLogoff > 400000000 then
            secsSinceLogoff = GetTimeStamp() - secsSinceLogoff
        end
        return displayName, note, playerStatus, secsSinceLogoff
    end

    GUILD_ROSTER_MANAGER:RefreshData()
    FRIENDS_LIST_MANAGER:RefreshData()
end

internal:AddModule(SocialListOfflineTimeFix:New())
